@@ -245,11 +245,12 @@ class AuthenticationCookie extends AuthenticationPlugin
                  </noscript>
                  <script type="text/javascript">
                     $(function() {
-                        $("#recaptcha_reload_btn").addClass("disableAjax");
-                        $("#recaptcha_switch_audio_btn").addClass("disableAjax");
-                        $("#recaptcha_switch_img_btn").addClass("disableAjax");
-                        $("#recaptcha_whatsthis_btn").addClass("disableAjax");
-                        $("#recaptcha_audio_play_again").live("mouseover", function() {
+                        $("#recaptcha_reload_btn," +
+                          "#recaptcha_switch_audio_btn," +
+                          "#recaptcha_switch_img_btn," +
+                          "#recaptcha_whatsthis_btn," +
+                          "#recaptcha_audio_play_again")
+                        .live("mouseover", function() {
                             $(this).addClass("disableAjax");
                         });
                     });
@@ -556,6 +557,16 @@ class AuthenticationCookie extends AuthenticationPlugin
         unset($_SERVER['PHP_AUTH_PW']);
 
         $_SESSION['last_access_time'] = time();
+    }
+
+    /**
+     * Stores user credentials after successful login.
+     *
+     * @return void
+     */
+    public function storeUserCredentials()
+    {
+        global $cfg;
 
         $this->createBlowfishIV();
 
