@@ -935,6 +935,9 @@ function PMA_setHistory($db, $table, $username, $sqlquery)
                NOW(),
                \'' . PMA_Util::sqlAddSlashes($sqlquery) . '\')'
     );
+
+    PMA_purgeHistory($username);
+
 } // end of 'PMA_setHistory()' function
 
 /**
@@ -1245,7 +1248,7 @@ function PMA_getForeignData(
                 }
             }
 
-            $disp  = $GLOBALS['dbi']->query(
+            $disp  = $GLOBALS['dbi']->tryQuery(
                 $f_query_main . $f_query_from . $f_query_filter
                 . $f_query_order . $f_query_limit
             );
@@ -1259,6 +1262,12 @@ function PMA_getForeignData(
                     $disp_row[] = $single_disp_row;
                 }
                 @$GLOBALS['dbi']->freeResult($disp);
+            } else {
+                // Either no data in the foreign table or
+                // user does not have select permission to foreign table/field
+                // Show an input field with a 'Browse foreign values' link
+                $disp_row = null;
+                $foreign_link = true;
             }
         } else {
             $disp_row = null;
@@ -1583,7 +1592,7 @@ function PMA_checkChildForeignReferences($db, $table, $column)
     $column_status['isReferenced'] = false;
     $column_status['isForeignKey'] = false;
     $column_status['references'] = array();
-    $foreigners = PMA_getForeigners($db, $table, $column);
+    $foreigners = PMA_getForeigners($db, $table, $column, 'foreign');
     $child_references = PMA_getChildReferences($db, $table, $column);
 
     if (sizeof($child_references, 0) > 0
