@@ -11,6 +11,8 @@ if (! defined('PHPMYADMIN')) {
 
 /**
  * Sets required globals
+ *
+ * @return void
  */
 function PMA_TRI_setGlobals()
 {
@@ -26,6 +28,8 @@ function PMA_TRI_setGlobals()
 
 /**
  * Main function for the triggers functionality
+ *
+ * @return void
  */
 function PMA_TRI_main()
 {
@@ -40,7 +44,7 @@ function PMA_TRI_main()
     /**
      * Display a list of available triggers
      */
-    $items = PMA_DBI_get_triggers($db, $table);
+    $items = $GLOBALS['dbi']->getTriggers($db, $table);
     echo PMA_RTE_getList('trigger', $items);
     /**
      * Display a link for adding a new trigger,
@@ -51,6 +55,8 @@ function PMA_TRI_main()
 
 /**
  * Handles editor requests for adding or editing an item
+ *
+ * @return void
  */
 function PMA_TRI_handleEditor()
 {
@@ -70,30 +76,32 @@ function PMA_TRI_handleEditor()
                 $trigger = PMA_TRI_getDataFromName($_REQUEST['item_original_name']);
                 $create_item = $trigger['create'];
                 $drop_item = $trigger['drop'] . ';';
-                $result = PMA_DBI_try_query($drop_item);
+                $result = $GLOBALS['dbi']->tryQuery($drop_item);
                 if (! $result) {
                     $errors[] = sprintf(
                         __('The following query has failed: "%s"'),
                         htmlspecialchars($drop_item)
                     )
                     . '<br />'
-                    . __('MySQL said: ') . PMA_DBI_getError(null);
+                    . __('MySQL said: ') . $GLOBALS['dbi']->getError(null);
                 } else {
-                    $result = PMA_DBI_try_query($item_query);
+                    $result = $GLOBALS['dbi']->tryQuery($item_query);
                     if (! $result) {
                         $errors[] = sprintf(
                             __('The following query has failed: "%s"'),
                             htmlspecialchars($item_query)
                         )
                         . '<br />'
-                        . __('MySQL said: ') . PMA_DBI_getError(null);
-                        // We dropped the old item, but were unable to create the new one
-                        // Try to restore the backup query
-                        $result = PMA_DBI_try_query($create_item);
+                        . __('MySQL said: ') . $GLOBALS['dbi']->getError(null);
+                        // We dropped the old item, but were unable to create the
+                        // new one. Try to restore the backup query.
+                        $result = $GLOBALS['dbi']->tryQuery($create_item);
                         if (! $result) {
-                            // OMG, this is really bad! We dropped the query, failed to create a new one
+                            // OMG, this is really bad! We dropped the query,
+                            // failed to create a new one
                             // and now even the backup query does not execute!
-                            // This should not happen, but we better handle this just in case.
+                            // This should not happen, but we better handle
+                            // this just in case.
                             $errors[] = __(
                                 'Sorry, we failed to restore the dropped trigger.'
                             )
@@ -101,34 +109,48 @@ function PMA_TRI_handleEditor()
                             . __('The backed up query was:')
                             . "\"" . htmlspecialchars($create_item) . "\""
                             . '<br />'
-                            . __('MySQL said: ') . PMA_DBI_getError(null);
+                            . __('MySQL said: ') . $GLOBALS['dbi']->getError(null);
                         }
                     } else {
-                        $message = PMA_Message::success(__('Trigger %1$s has been modified.'));
-                        $message->addParam(PMA_backquote($_REQUEST['item_name']));
+                        $message = PMA_Message::success(
+                            __('Trigger %1$s has been modified.')
+                        );
+                        $message->addParam(
+                            PMA_Util::backquote($_REQUEST['item_name'])
+                        );
                         $sql_query = $drop_item . $item_query;
                     }
                 }
             } else {
                 // 'Add a new item' mode
-                $result = PMA_DBI_try_query($item_query);
+                $result = $GLOBALS['dbi']->tryQuery($item_query);
                 if (! $result) {
                     $errors[] = sprintf(
                         __('The following query has failed: "%s"'),
                         htmlspecialchars($item_query)
                     )
                     . '<br /><br />'
-                    . __('MySQL said: ') . PMA_DBI_getError(null);
+                    . __('MySQL said: ') . $GLOBALS['dbi']->getError(null);
                 } else {
-                    $message = PMA_Message::success(__('Trigger %1$s has been created.'));
-                    $message->addParam(PMA_backquote($_REQUEST['item_name']));
+                    $message = PMA_Message::success(
+                        __('Trigger %1$s has been created.')
+                    );
+                    $message->addParam(
+                        PMA_Util::backquote($_REQUEST['item_name'])
+                    );
                     $sql_query = $item_query;
                 }
             }
         }
 
         if (count($errors)) {
-            $message = PMA_Message::error(__('<b>One or more errors have occured while processing your request:</b>'));
+            $message = PMA_Message::error(
+                '<b>'
+                . __(
+                    'One or more errors have occurred while processing your request:'
+                )
+                . '</b>'
+            );
             $message->addString('<ul>');
             foreach ($errors as $string) {
                 $message->addString('<li>' . $string . '</li>');
@@ -136,38 +158,48 @@ function PMA_TRI_handleEditor()
             $message->addString('</ul>');
         }
 
-        $output = PMA_showMessage($message, $sql_query);
+        $output = PMA_Util::getMessage($message, $sql_query);
         if ($GLOBALS['is_ajax_request']) {
-            $extra_data = array();
+            $response = PMA_Response::getInstance();
             if ($message->isSuccess()) {
-                $items = PMA_DBI_get_triggers($db, $table, '');
+                $items = $GLOBALS['dbi']->getTriggers($db, $table, '');
                 $trigger = false;
                 foreach ($items as $value) {
                     if ($value['name'] == $_REQUEST['item_name']) {
                         $trigger = $value;
                     }
                 }
-                $extra_data['insert'] = false;
-                if (empty($table) || ($trigger !== false && $table == $trigger['table'])) {
-                    $extra_data['insert'] = true;
-                    $extra_data['new_row'] = PMA_TRI_getRowForList($trigger);
-                    $extra_data['name'] = htmlspecialchars(
-                        strtoupper($_REQUEST['item_name'])
+                $insert = false;
+                if (empty($table)
+                    || ($trigger !== false && $table == $trigger['table'])
+                ) {
+                    $insert = true;
+                    $response->addJSON('new_row', PMA_TRI_getRowForList($trigger));
+                    $response->addJSON(
+                        'name',
+                        htmlspecialchars(
+                            strtoupper($_REQUEST['item_name'])
+                        )
                     );
                 }
-                $response = $output;
+                $response->addJSON('insert', $insert);
+                $response->addJSON('message', $output);
             } else {
-                $response = $message;
+                $response->addJSON('message', $message);
+                $response->isSuccess(false);
             }
-            PMA_ajaxResponse($response, $message->isSuccess(), $extra_data);
+            exit;
         }
     }
 
     /**
      * Display a form used to add/edit a trigger, if necessary
      */
-    if (count($errors) || ( empty($_REQUEST['editor_process_add']) && empty($_REQUEST['editor_process_edit'])
-        && (! empty($_REQUEST['add_item']) || ! empty($_REQUEST['edit_item']))) // FIXME: this must be simpler than that
+    if (count($errors)
+        || (empty($_REQUEST['editor_process_add'])
+        && empty($_REQUEST['editor_process_edit'])
+        && (! empty($_REQUEST['add_item'])
+        || ! empty($_REQUEST['edit_item']))) // FIXME: this must be simpler than that
     ) {
         // Get the data for the form (if any)
         if (! empty($_REQUEST['add_item'])) {
@@ -192,24 +224,27 @@ function PMA_TRI_handleEditor()
             // Show form
             $editor = PMA_TRI_getEditorForm($mode, $item);
             if ($GLOBALS['is_ajax_request']) {
-                $extra_data = array('title' => $title);
-                PMA_ajaxResponse($editor, true, $extra_data);
+                $response = PMA_Response::getInstance();
+                $response->addJSON('message', $editor);
+                $response->addJSON('title', $title);
             } else {
                 echo "\n\n<h2>$title</h2>\n\n$editor";
                 unset($_POST);
-                include './libraries/footer.inc.php';
             }
-            // exit;
+            exit;
         } else {
-            $message  = __('Error in processing request') . ' : ';
+            $message  = __('Error in processing request:') . ' ';
             $message .= sprintf(
                 PMA_RTE_getWord('not_found'),
-                htmlspecialchars(PMA_backquote($_REQUEST['item_name'])),
-                htmlspecialchars(PMA_backquote($db))
+                htmlspecialchars(PMA_Util::backquote($_REQUEST['item_name'])),
+                htmlspecialchars(PMA_Util::backquote($db))
             );
             $message = PMA_message::error($message);
             if ($GLOBALS['is_ajax_request']) {
-                PMA_ajaxResponse($message, false);
+                $response = PMA_Response::getInstance();
+                $response->isSuccess(false);
+                $response->addJSON('message', $message);
+                exit;
             } else {
                 $message->display();
             }
@@ -220,7 +255,7 @@ function PMA_TRI_handleEditor()
 /**
  * This function will generate the values that are required to for the editor
  *
- * @return  array    Data necessary to create the editor.
+ * @return array    Data necessary to create the editor.
  */
 function PMA_TRI_getDataFromRequest()
 {
@@ -242,16 +277,16 @@ function PMA_TRI_getDataFromRequest()
  * This function will generate the values that are required to complete
  * the "Edit trigger" form given the name of a trigger.
  *
- * @param   string   $name   The name of the trigger.
+ * @param string $name The name of the trigger.
  *
- * @return  array    Data necessary to create the editor.
+ * @return array Data necessary to create the editor.
  */
 function PMA_TRI_getDataFromName($name)
 {
     global $db, $table, $_REQUEST;
 
     $temp = array();
-    $items = PMA_DBI_get_triggers($db, $table, '');
+    $items = $GLOBALS['dbi']->getTriggers($db, $table, '');
     foreach ($items as $value) {
         if ($value['name'] == $name) {
             $temp = $value;
@@ -276,13 +311,12 @@ function PMA_TRI_getDataFromName($name)
 /**
  * Displays a form used to add/edit a trigger
  *
- * @param   string   $mode         If the editor will be used edit a trigger
- *                                 or add a new one: 'edit' or 'add'.
- * @param   array    $item         Data for the trigger returned by
- *                                 PMA_TRI_getDataFromRequest() or
- *                                 PMA_TRI_getDataFromName()
+ * @param string $mode If the editor will be used edit a trigger
+ *                     or add a new one: 'edit' or 'add'.
+ * @param array  $item Data for the trigger returned by PMA_TRI_getDataFromRequest()
+ *                     or PMA_TRI_getDataFromName()
  *
- * @return  string   HTML code for the editor.
+ * @return string HTML code for the editor.
  */
 function PMA_TRI_getEditorForm($mode, $item)
 {
@@ -296,7 +330,7 @@ function PMA_TRI_getEditorForm($mode, $item)
                        'item_definer'
                    );
     foreach ($need_escape as $key => $index) {
-        $item[$index] = htmlentities($item[$index], ENT_QUOTES);
+        $item[$index] = htmlentities($item[$index], ENT_QUOTES, 'UTF-8');
     }
     $original_data = '';
     if ($mode == 'edit') {
@@ -304,9 +338,9 @@ function PMA_TRI_getEditorForm($mode, $item)
                        . "type='hidden' value='{$item['item_original_name']}'/>\n";
     }
     $query  = "SELECT `TABLE_NAME` FROM `INFORMATION_SCHEMA`.`TABLES` ";
-    $query .= "WHERE `TABLE_SCHEMA`='" . PMA_sqlAddSlashes($db) . "' ";
+    $query .= "WHERE `TABLE_SCHEMA`='" . PMA_Util::sqlAddSlashes($db) . "' ";
     $query .= "AND `TABLE_TYPE`='BASE TABLE'";
-    $tables = PMA_DBI_fetch_result($query);
+    $tables = $GLOBALS['dbi']->fetchResult($query);
 
     // Create the output
     $retval  = "";
@@ -314,7 +348,7 @@ function PMA_TRI_getEditorForm($mode, $item)
     $retval .= "<form class='rte_form' action='db_triggers.php' method='post'>\n";
     $retval .= "<input name='{$mode}_item' type='hidden' value='1' />\n";
     $retval .= $original_data;
-    $retval .= PMA_generate_common_hidden_inputs($db, $table) . "\n";
+    $retval .= PMA_URL_getHiddenInputs($db, $table) . "\n";
     $retval .= "<fieldset>\n";
     $retval .= "<legend>" . __('Details') . "</legend>\n";
     $retval .= "<table class='rte_table' style='width: 100%'>\n";
@@ -401,7 +435,7 @@ function PMA_TRI_getEditorForm($mode, $item)
 /**
  * Composes the query necessary to create a trigger from an HTTP request.
  *
- * @return  string  The CREATE TRIGGER query.
+ * @return string  The CREATE TRIGGER query.
  */
 function PMA_TRI_getQueryFromRequest()
 {
@@ -411,33 +445,39 @@ function PMA_TRI_getQueryFromRequest()
     if (! empty($_REQUEST['item_definer'])) {
         if (strpos($_REQUEST['item_definer'], '@') !== false) {
             $arr = explode('@', $_REQUEST['item_definer']);
-            $query .= 'DEFINER=' . PMA_backquote($arr[0]);
-            $query .= '@' . PMA_backquote($arr[1]) . ' ';
+            $query .= 'DEFINER=' . PMA_Util::backquote($arr[0]);
+            $query .= '@' . PMA_Util::backquote($arr[1]) . ' ';
         } else {
-            $errors[] = __('The definer must be in the "username@hostname" format');
+            $errors[] = __('The definer must be in the "username@hostname" format!');
         }
     }
     $query .= 'TRIGGER ';
     if (! empty($_REQUEST['item_name'])) {
-        $query .= PMA_backquote($_REQUEST['item_name']) . ' ';
+        $query .= PMA_Util::backquote($_REQUEST['item_name']) . ' ';
     } else {
-        $errors[] = __('You must provide a trigger name');
+        $errors[] = __('You must provide a trigger name!');
     }
-    if (! empty($_REQUEST['item_timing']) && in_array($_REQUEST['item_timing'], $action_timings)) {
+    if (! empty($_REQUEST['item_timing'])
+        && in_array($_REQUEST['item_timing'], $action_timings)
+    ) {
         $query .= $_REQUEST['item_timing'] . ' ';
     } else {
-        $errors[] = __('You must provide a valid timing for the trigger');
+        $errors[] = __('You must provide a valid timing for the trigger!');
     }
-    if (! empty($_REQUEST['item_event']) && in_array($_REQUEST['item_event'], $event_manipulations)) {
+    if (! empty($_REQUEST['item_event'])
+        && in_array($_REQUEST['item_event'], $event_manipulations)
+    ) {
         $query .= $_REQUEST['item_event'] . ' ';
     } else {
-        $errors[] = __('You must provide a valid event for the trigger');
+        $errors[] = __('You must provide a valid event for the trigger!');
     }
     $query .= 'ON ';
-    if (! empty($_REQUEST['item_table']) && in_array($_REQUEST['item_table'], PMA_DBI_get_tables($db))) {
-        $query .= PMA_backQuote($_REQUEST['item_table']);
+    if (! empty($_REQUEST['item_table'])
+        && in_array($_REQUEST['item_table'], $GLOBALS['dbi']->getTables($db))
+    ) {
+        $query .= PMA_Util::backquote($_REQUEST['item_table']);
     } else {
-        $errors[] = __('You must provide a valid table name');
+        $errors[] = __('You must provide a valid table name!');
     }
     $query .= ' FOR EACH ROW ';
     if (! empty($_REQUEST['item_definition'])) {
